@@ -440,7 +440,8 @@ parseOverdriveVoltCurve(std::vector<std::string> const &ppOdClkVoltageLines)
       targetIt = std::next(targetIt);
     }
 
-    return std::move(points);
+    if (!points.empty())
+      return std::move(points);
   }
 
   return {};
@@ -673,7 +674,12 @@ bool hasOverdriveVoltCurveControl(std::vector<std::string> const &data)
         return line.find("OD_VDDC_CURVE:") != std::string::npos;
       });
 
-  return curveIt != data.cend();
+  if (curveIt != data.cend() && std::next(curveIt) != data.cend()) {
+    auto point = parseOverdriveClkVoltLine(*std::next(curveIt));
+    return point.has_value();
+  }
+
+  return false;
 }
 
 bool hasOverdriveVoltOffsetControl(std::vector<std::string> const &data)
